# Superfence

!!! tip
    Reference for PyMdown Extensions Superfences can be found [here](https://facelessuser.github.io/pymdown-extensions/extensions/superfences/#custom-fences).

::: rst_in_md.superfence_formatter
    :type: function

::: rst_in_md.superfence_validator
    :type: function

::: rst_in_md.RestructuredTextInMarkdownAutoConfigurator
